import pytest

from si_tests import logger
from si_tests import settings

LOG = logger.logger


@pytest.mark.usefixtures('log_step_time')
@pytest.mark.usefixtures('log_method_time')
def test_host_os_configuration(kaas_manager, show_step):
    """Test day 2 operations performed by means of Ansible modules

     Scenario:
        1. Create HostOSconfiguration object for several machines
        2. Wait for new state items in LCMcluster
        3. Check that machines from hostosconfiguration status field have been chosen correctly
        4. Check LCMmachine stateItems
        5. Go to machines and ensure that changes are applied only on machineSelector-chosen ones
     """
    cluster_name = settings.CLUSTER_NAME
    cluster_ns = settings.CLUSTER_NAMESPACE
    ns = kaas_manager.get_namespace(namespace=cluster_ns)
    cluster = ns.get_cluster(cluster_name)
    hostoscfg_name = cluster_name + '-test'

    sysctl_opts = {
        "kernel.sysrq": 100500,
        "net.ipv4.ip_forward": 1
    }

    package_opts = {
        "elinks": "present"
    }

    hostoscfg_data = {
        "apiVersion": "kaas.mirantis.com/v1alpha1",
        "kind": "HostOSConfiguration",
        "metadata": {
            "name": hostoscfg_name,
            "namespace": cluster_ns
        },
        "spec": {
            "configs": [
                {
                    "module": "sysctl",
                    "moduleVersion": "1.0.0",
                    "values": sysctl_opts
                },
                {
                    "module": "package",
                    "moduleVersion": "1.0.0",
                    "values": package_opts
                }
            ],
            "machineSelector": {
                "matchLabels": {
                    "cluster.sigs.k8s.io/control-plane": "true"
                }
            }
        }
    }

    show_step(1)
    hostoscfg = None
    hostoscfg_list = cluster.get_hostosconfigurations(name_prefix=cluster_name)
    if not hostoscfg_list:
        hostoscfg = cluster.create_hostosconfiguration_raw(hostoscfg_data)
    else:
        for hostoscfg_elem in hostoscfg_list:
            if hostoscfg_elem.name == hostoscfg_name:
                hostoscfg = hostoscfg_elem
                break
        if not hostoscfg:
            raise Exception(f'There is no HostOSConfig resource with name {hostoscfg_name}')

    show_step(2)
    # Check that new items added into machineTypes in LCMCluster
    cluster.check.wait_lcmcluster_day2_machinetypes(hostoscfg)

    show_step(3)
    # Check that machines from hostosconfiguration status field
    # have labels used for machineSelector
    machine_names = cluster.check.check_hostosconfig_machine_selector(hostoscfg)

    show_step(4)
    # Check that new items has been added into stateItems in LCMMachine
    cluster.check.wait_lcmmachine_day2_stateitems(hostoscfg)

    show_step(5)
    # Go to machines and check that sysctl options changed, packages installed
    # on selected by machineSelector and no changes made on other machines
    cluster.check.check_day2_sysctl_module_results(hostoscfg, machine_names)
    cluster.check.check_day2_package_module_results(hostoscfg, machine_names)
